# Changelog

## [0.1.2](https://github.com/Maxl94/yaai/compare/v0.1.1...v0.1.2) (2026-02-19)


### Bug Fixes

* updates alembic configuration and adjusts paths in main.py ([2c6ee40](https://github.com/Maxl94/yaai/commit/2c6ee40595ec9105257fa76423851db320a8de44))

## [0.1.1](https://github.com/Maxl94/yaai/compare/v0.1.0...v0.1.1) (2026-02-16)


### Documentation

* corrects package name ([319ca9d](https://github.com/Maxl94/yaai/commit/319ca9d673476a1d6e7845dd86e63bf2983d69ba))
* update install commands and fix build for yaai-monitoring rename ([88a9921](https://github.com/Maxl94/yaai/commit/88a992117a0a975778ca6faca428390feed9ce21))

## [0.1.0](https://github.com/Maxl94/yaai/compare/v0.1.0...v0.1.0) (2026-02-16)


### Features

* initial release of YAAI platform ([0662d48](https://github.com/Maxl94/yaai/commit/0662d48b222c61be92b36490b675182b69dcddb7))


### Documentation

* adds license and contribution guide ([6b43d92](https://github.com/Maxl94/yaai/commit/6b43d92573690c789ebcaa904971ebab8559dfb7))
* adds logo and screenshots ([aed0900](https://github.com/Maxl94/yaai/commit/aed0900bbbe14e253f8c23434e4f17df70a00aed))
* adds readme ([0b88f1e](https://github.com/Maxl94/yaai/commit/0b88f1e6a8f24c52b404f5eff2062bf0aa9d6200))
* updates screenshots ([3399ac3](https://github.com/Maxl94/yaai/commit/3399ac308d42cf9f57f1b6f8b335c92826826b19))


### Miscellaneous Chores

* rename package to align with PyPI ([fdad286](https://github.com/Maxl94/yaai/commit/fdad2865a091c13545e08867a7ceec3d72b68ee6))

## [0.1.0](https://github.com/Maxl94/yaai/compare/v0.1.0...v0.1.0) (2026-02-16)


### Miscellaneous Chores

* rename package to align with PyPI ([fdad286](https://github.com/Maxl94/yaai/commit/fdad2865a091c13545e08867a7ceec3d72b68ee6))

## 0.1.0 (2026-02-16)


### Features

* initial release of YAAI platform ([0662d48](https://github.com/Maxl94/yaai/commit/0662d48b222c61be92b36490b675182b69dcddb7))


### Documentation

* adds license and contribution guide ([6b43d92](https://github.com/Maxl94/yaai/commit/6b43d92573690c789ebcaa904971ebab8559dfb7))
* adds logo and screenshots ([aed0900](https://github.com/Maxl94/yaai/commit/aed0900bbbe14e253f8c23434e4f17df70a00aed))
* adds readme ([0b88f1e](https://github.com/Maxl94/yaai/commit/0b88f1e6a8f24c52b404f5eff2062bf0aa9d6200))
* updates screenshots ([3399ac3](https://github.com/Maxl94/yaai/commit/3399ac308d42cf9f57f1b6f8b335c92826826b19))
